Some files running various parts of the eazy-py code, e.g., for generating
templates and testing.

*(Oct. 2024) NB:* These scripts haven't been used or tested in years and should be
considered deprecated.